@@ -3,7 +3,7 @@ use plotly::common::{
     ColorScale, ColorScalePalette, DashType, Fill, Font, Line, LineShape, Marker, Mode, Title,
 };
 use plotly::layout::{Axis, BarMode, Layout, Legend, TicksDirection};
-use plotly::{Bar, NamedColor, Plot, Rgb, Rgba, Scatter};
+use plotly::{Bar, NamedColor, Plot, Rgb, Rgba, Scatter, ScatterPolar};
 use rand_distr::{Distribution, Normal, Uniform};
 
 // Scatter Plots
@@ -23,21 +23,21 @@ fn simple_scatter_plot(show: bool) {
 
 fn line_and_scatter_plots(show: bool) {
     let n: usize = 100;
-    let rng = rand::thread_rng();
+    let mut rng = rand::thread_rng();
     let random_x: Vec<f64> = linspace(0., 1., n).collect();
     let random_y0: Vec<f64> = Normal::new(5., 1.)
         .unwrap()
-        .sample_iter(rng)
+        .sample_iter(&mut rng)
         .take(n)
         .collect();
     let random_y1: Vec<f64> = Normal::new(0., 1.)
         .unwrap()
-        .sample_iter(rng)
+        .sample_iter(&mut rng)
         .take(n)
         .collect();
     let random_y2: Vec<f64> = Normal::new(-5., 1.)
         .unwrap()
-        .sample_iter(rng)
+        .sample_iter(&mut rng)
         .take(n)
         .collect();
 
@@ -82,6 +82,27 @@ fn bubble_scatter_plots(show: bool) {
     println!("{}", plot.to_inline_html(Some("bubble_scatter_plots")));
 }
 
+fn polar_scatter_plot(show: bool) {
+    let n: usize = 400;
+    let theta: Vec<f64> = linspace(0., 360., n).collect();
+    let r: Vec<f64> = theta
+        .iter()
+        .map(|x| {
+            let x = x / 360. * core::f64::consts::TAU;
+            let x = x.cos();
+            1. / 8. * (63. * x.powf(5.) - 70. * x.powf(3.) + 15. * x).abs()
+        })
+        .collect();
+
+    let trace = ScatterPolar::new(theta, r).mode(Mode::Lines);
+    let mut plot = Plot::new();
+    plot.add_trace(trace);
+    if show {
+        plot.show();
+    }
+    println!("{}", plot.to_inline_html(Some("polar_scatter_plot")));
+}
+
 fn data_labels_hover(show: bool) {
     let trace1 = Scatter::new(vec![1, 2, 3, 4, 5], vec![1, 6, 3, 6, 1])
         .mode(Mode::Markers)
@@ -224,16 +245,16 @@ fn colored_and_styled_scatter_plot(show: bool) {
 
 fn large_data_sets(show: bool) {
     let n: usize = 100_000;
-    let rng = rand::thread_rng();
-    let r: Vec<f64> = Uniform::new(0., 1.).sample_iter(rng).take(n).collect();
+    let mut rng = rand::thread_rng();
+    let r: Vec<f64> = Uniform::new(0., 1.).sample_iter(&mut rng).take(n).collect();
     let theta: Vec<f64> = Normal::new(0., 2. * std::f64::consts::PI)
         .unwrap()
-        .sample_iter(rng)
+        .sample_iter(&mut rng)
         .take(n)
         .collect();
     let colors: Vec<f64> = Normal::new(0., 1.)
         .unwrap()
-        .sample_iter(rng)
+        .sample_iter(&mut rng)
         .take(n)
         .collect();
 
@@ -594,6 +615,7 @@ fn main() -> std::io::Result<()> {
     simple_scatter_plot(true);
     line_and_scatter_plots(true);
     bubble_scatter_plots(true);
+    polar_scatter_plot(true);
     data_labels_hover(true);
     data_labels_on_the_plot(true);
     colored_and_styled_scatter_plot(true);
