@@ -1,13 +1,14 @@
-//! # Plotly for Rust
+//! # Plotly.rs
 //!
 //! A plotting library for Rust powered by [Plotly.js](https://plot.ly/javascript/).
 
 #![allow(dead_code)]
 extern crate askama;
-extern crate num;
 extern crate rand;
 extern crate serde;
 
+pub mod ndarray;
+
 pub mod layout;
 pub mod plot;
 
@@ -20,6 +21,7 @@ pub mod heat_map;
 pub mod histogram;
 pub mod ohlc;
 pub mod scatter;
+pub mod scatter_polar;
 pub mod surface;
 
 pub use crate::layout::Layout;
@@ -34,6 +36,7 @@ pub use crate::heat_map::HeatMap;
 pub use crate::histogram::Histogram;
 pub use crate::ohlc::Ohlc;
 pub use crate::scatter::Scatter;
+pub use crate::scatter_polar::ScatterPolar;
 pub use crate::surface::Surface;
 
 pub use crate::common::color::NamedColor;
@@ -42,6 +45,9 @@ pub use crate::common::color::Rgba;
 
 pub use crate::plot::Trace;
 
+#[cfg(feature = "plotly_ndarray")]
+pub use crate::ndarray::ArrayTraces;
+
 // Not public API.
 #[doc(hidden)]
 pub mod private;
