@@ -12,10 +12,10 @@ use std::process::Command;
 use crate::Layout;
 use rand_distr::Alphanumeric;
 
-const PLOTLY_JS: &str = "plotly-1.54.6.min.js";
+const PLOTLY_JS: &str = "plotly-2.8.3.min.js";
 
 #[derive(Template)]
-#[template(path = "plotly-1.54.6.min.js", escape = "none")]
+#[template(path = "plotly-2.8.3.min.js", escape = "none")]
 struct PlotlyJs;
 
 #[derive(Template)]
@@ -54,7 +54,6 @@ pub enum ImageFormat {
     EPS,
 }
 
-
 /// A struct that implements `Trace` can be serialized to json format that is understood by Plotly.js.
 pub trait Trace {
     fn serialize(&self) -> String;
@@ -120,7 +119,6 @@ plot.save("filename", ImageFormat::PNG, width, height, scale);
 See https://igiagkiozis.github.io/plotly/content/getting_started.html for further details.
 "#;
 
-
 impl Plot {
     /// Create a new `Plot`.
     pub fn new() -> Plot {
@@ -164,10 +162,13 @@ impl Plot {
         let rendered = rendered.as_bytes();
         let mut temp = env::temp_dir();
 
-        let mut plot_name = rand::thread_rng()
-            .sample_iter(&rand::distributions::Alphanumeric)
-            .take(22)
-            .collect::<String>();
+        let mut plot_name = String::from_utf8(
+            thread_rng()
+                .sample_iter(&Alphanumeric)
+                .take(22)
+                .collect::<Vec<u8>>(),
+        )
+        .unwrap();
         plot_name.push_str(".html");
         plot_name = format!("plotly_{}", plot_name);
 
@@ -191,10 +192,13 @@ impl Plot {
         let rendered = rendered.as_bytes();
         let mut temp = env::temp_dir();
 
-        let mut plot_name = rand::thread_rng()
-            .sample_iter(&rand::distributions::Alphanumeric)
-            .take(22)
-            .collect::<String>();
+        let mut plot_name = String::from_utf8(
+            thread_rng()
+                .sample_iter(&Alphanumeric)
+                .take(22)
+                .collect::<Vec<u8>>(),
+        )
+        .unwrap();
         plot_name.push_str(".html");
 
         temp.push(plot_name);
@@ -217,10 +221,13 @@ impl Plot {
         let rendered = rendered.as_bytes();
         let mut temp = env::temp_dir();
 
-        let mut plot_name = rand::thread_rng()
-            .sample_iter(&rand::distributions::Alphanumeric)
-            .take(22)
-            .collect::<String>();
+        let mut plot_name: String = String::from_utf8(
+            thread_rng()
+                .sample_iter(&Alphanumeric)
+                .take(22)
+                .collect::<Vec<u8>>(),
+        )
+        .unwrap();
         plot_name.push_str(".html");
 
         temp.push(plot_name);
@@ -239,11 +246,25 @@ impl Plot {
     ///
     /// In contrast to `Plot::show()` this will save the resulting html in a user specified location
     /// instead of the system temp directory.
+    ///
+    /// In contrast to `Plot::write_html`, this will save the resulting html to a file located at a
+    /// user specified location, instead of a writing it to anything that implements `std::io::Write`.
     pub fn to_html<P: AsRef<Path>>(&self, filename: P) {
+        let mut file = File::create(filename.as_ref()).unwrap();
+
+        self.write_html(&mut file);
+    }
+
+    /// Renders the contents of the `Plot` to HTML and outputs them to a writable buffer.
+    ///
+    /// In contrast to `Plot::to_html`, this will save the resulting html to a byte buffer using the
+    /// `std::io::Write` trait, instead of to a user specified file.
+    pub fn write_html<W: Write>(&self, buffer: &mut W) {
         let rendered = self.render(false, "", 0, 0);
         let rendered = rendered.as_bytes();
-        let mut file = File::create(filename.as_ref()).unwrap();
-        file.write_all(rendered)
+
+        buffer
+            .write_all(rendered)
             .expect("failed to write html output");
     }
 
@@ -260,14 +281,26 @@ impl Plot {
         match plot_div_id {
             Some(id) => self.render_inline(id.as_ref()),
             None => {
-                let rand_id: String = thread_rng().sample_iter(&Alphanumeric).take(20).collect();
+                let rand_id = String::from_utf8(
+                    thread_rng()
+                        .sample_iter(&Alphanumeric)
+                        .take(20)
+                        .collect::<Vec<u8>>(),
+                )
+                .unwrap();
                 self.render_inline(rand_id.as_str())
             }
         }
     }
 
     fn to_jupyter_notebook_html(&self) -> String {
-        let plot_div_id: String = thread_rng().sample_iter(&Alphanumeric).take(20).collect();
+        let plot_div_id = String::from_utf8(
+            thread_rng()
+                .sample_iter(&Alphanumeric)
+                .take(20)
+                .collect::<Vec<u8>>(),
+        )
+        .unwrap();
         let plot_data = self.render_plot_data();
 
         let tmpl = JupyterNotebookPlotTemplate {
@@ -280,7 +313,10 @@ impl Plot {
     /// Display plot in Jupyter Notebook.
     pub fn notebook_display(&self) {
         let plot_data = self.to_jupyter_notebook_html();
-        println!("EVCXR_BEGIN_CONTENT text/html\n{}\nEVCXR_END_CONTENT", plot_data);
+        println!(
+            "EVCXR_BEGIN_CONTENT text/html\n{}\nEVCXR_END_CONTENT",
+            plot_data
+        );
     }
 
     /// Display plot in Jupyter Lab.
@@ -342,7 +378,7 @@ impl Plot {
             let s = trace.serialize();
             plot_data.push_str(format!("var trace_{} = {};\n", idx, s).as_str());
         }
-        // plot_data.push_str("\n");
+
         plot_data.push_str("var data = [");
         for idx in 0..self.traces.len() {
             if idx != self.traces.len() - 1 {
@@ -412,14 +448,14 @@ impl Plot {
         for (index, data) in plot_data.iter().enumerate() {
             if index < plot_data.len() - 1 {
                 json_data.push_str(data);
-                json_data.push_str(r#","#);
+                json_data.push(',');
             } else {
                 json_data.push_str(data);
-                json_data.push_str("]");
+                json_data.push(']');
             }
         }
         json_data.push_str(format!(r#", "layout": {}"#, layout_data).as_str());
-        json_data.push_str("}");
+        json_data.push('}');
         json_data
     }
 
